@@ -3,10 +3,6 @@
 NG PyTest Salt Plugin
 """
 # pragma: no cover
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import os
 import re
 import sys
