@@ -5,10 +5,6 @@
 
     Salt Daemon Factories PyTest Plugin
 """
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import logging
 import os
 import pprint
