@@ -5,10 +5,6 @@
 
     PyTest Markers related utilities
 """
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import contextlib
 import logging
 import os
