@@ -3,10 +3,6 @@
 tests.functional.factories.conftest
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 """
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import mock
 import pytest
 
