@@ -5,10 +5,6 @@
 
     Test Salt's base script implementation
 """
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import json
 import sys
 from collections import OrderedDict
